from django.db import models

# Import User
from django.contrib.auth.models import User

import urllib2


class FacebookSessionError(Exception):

    def __init__(self, error_type, message):
        self.message = message
        self.type = error_type

    def get_message(self):
        return self.message

    def get_type(self):
        return self.type

    def __unicode__(self):
        return u'%s: "%s"' % (self.type, self.message)


class FacebookSession(models.Model):

    access_token = models.CharField(max_length=103, unique=True)
    expires = models.IntegerField(null=True)

    user = models.ForeignKey(User, null=True)
    uid = models.BigIntegerField(unique=True, null=True)

    class Meta:
        unique_together = (('user', 'uid'), ('access_token', 'expires'))

    def query(self, object_id, connection_type=None, metadata=False):
        import urllib
        import json

        url = 'https://graph.facebook.com/v2.8/%s' % (object_id)
        if connection_type:
            url += '/%s' % (connection_type)

	params = {
                'access_token': self.access_token,
                'fields': 'name,email,first_name,last_name'
                }
        if metadata:
            params['metadata'] = 1

        url += '?' + urllib.urlencode(params)
        response = json.loads(urllib2.urlopen(url).read())

        if 'error' in response:
            error = response['error']
            raise FacebookSessionError(error['type'], error['message'])

        return response



from django.shortcuts import render
from django.http import HttpResponseRedirect
from django.contrib import auth
from models import FacebookSession
from django.conf import settings

import json
import urllib


class FacebookLoginMixin(object):
    template_name = "login.html"
    login_settings = settings
    redirect_path = '/'

    def dispatch(self, request, *args, **kwargs):
        if request.user.is_authenticated():
            return HttpResponseRedirect(self.redirect_path)
	return super(FacebookLoginMixin, self).dispatch(request, *args, **kwargs)

    def get(self, request, *args, **kwargs):

        if 'code' in request.GET:
            args = {
                'client_id': settings.FACEBOOK_APP_ID,
                'redirect_uri': settings.FACEBOOK_REDIRECT_URI,
                'client_secret': settings.FACEBOOK_APP_SECRET,
                'code': request.GET['code']
            }
            url = 'https://graph.facebook.com/oauth/access_token?'
            url = url + urllib.urlencode(args)
            response = json.loads(urllib.urlopen(url))
            access_token = response['access_token'][0]
            expires = response['expires'][0]

	    facebook_session = FacebookSession.objects.get_or_create(access_token=access_token)[0]
            facebook_session.expires = expires
            facebook_session.save()
            user = auth.authenticate(token=access_token)

            if user:
                if user.is_active:
                    auth.login(request, user)
                    return HttpResponseRedirect(self.redirect_path)

	context = {
	    'settings': self.login_settings
	}
        return render(request, self.template_name, context)



#!/usr/bin/env
# -*- coding: utf-8 -*-

from setuptools import find_packages, setup
from os import path

def read(name):
    return open(path.join(path.dirname(__file__), name)).read()

setup(
    name='django-facebook-auth-helper',
    version='0.1.5',
    description="Django implementation for Facebook authentication.",
    long_description=read("README.rst"),
    url="https://github.com/pinetree408/django-facebook-auth",
    maintainer="Sangyoon Lee",
    maintainer_email="pinetree408@gmail.com",
    author='Sangyoon Lee',
    author_email='pinetree408@gmail.com',
    license='MIT License',
    install_requires=(
        'Django==1.7',
    ),
    classifiers=[
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 2.7',
        'Topic :: Internet :: WWW/HTTP',
    ],
    packages=[
        'django_facebook_auth',
    ],
    keywords='django facebook authentication',
)
